# Speed Benchmark

A generic speed benchmark library. It runs every function with every arg to get the average time cost and also checks the result.

## Installation

```bash
pip install speed-benchmark
```

## Contribution

See [contribution docs](docs/get_started/contribution.md) for details.

## Release versions

We use [setuptools_scm](https://github.com/pypa/setuptools_scm/) for versioning. For the versions available, see the [tags](https://github.com/shenmishajing/speed_benchmark/tags) on this repository.

## License

This project is licensed under the MIT License.

## Star History

<picture>
  <source
    media="(prefers-color-scheme: dark)"
    srcset="
      https://api.star-history.com/svg?repos=shenmishajing/speed_benchmark&type=Date&theme=dark
    "
  />
  <source
    media="(prefers-color-scheme: light)"
    srcset="
      https://api.star-history.com/svg?repos=shenmishajing/speed_benchmark&type=Date
    "
  />
  <img
    alt="Star History Chart"
    src="https://api.star-history.com/svg?repos=shenmishajing/speed_benchmark&type=Date"
  />
</picture>
